@@ -1,9 +1,7 @@
 import straxen
 import strax
-
 import numpy as np
 import matplotlib.pyplot as plt
-from matplotlib.backends.backend_pdf import PdfPages
 import os
 
 
@@ -39,7 +37,6 @@ def plot_pulses(context, raw_records, run_id, time_range,
                 detector_ending=''):
     """
     Plots nveto pulses for a list of records.
-
     :param context: Context to be used.
     :param plot_hits: If True plot hit boundaries including the left
         and right extension as orange shaded regions.
@@ -63,7 +60,8 @@ def plot_pulses(context, raw_records, run_id, time_range,
     records = strax.sort_by_time(records)
     strax.zero_out_of_bounds(records)
 
-    baseline_key = 'baseline_samples'+detector_ending
+    baseline_key = [key for key  in p.config.keys() if 'baseline_samples' in key][0]
+
     if isinstance(p.config[baseline_key], int):
         baseline_samples = p.config[baseline_key]
     else:
@@ -76,6 +74,7 @@ def plot_pulses(context, raw_records, run_id, time_range,
 
     nfigs = 1
     if store_pdf:
+        from matplotlib.backends.backend_pdf import PdfPages
         fname = f'pulses_{run_id}_{time_range[0]}_{time_range[1]}.pdf'
         fname = os.path.join(path, fname)
         pdf = PdfPages(fname)
@@ -101,6 +100,13 @@ def plot_pulses(context, raw_records, run_id, time_range,
                           [baseline - baseline_rms] * 2,
                           color='gray', alpha=0.4
                           )
+        
+        # check type of p.hit_thresholds
+        if isinstance(p.hit_thresholds,int):
+            thr = p.hit_thresholds
+        elif isinstance(p.hit_thresholds,np.ndarray):
+            thr = p.hit_thresholds[rr_pulse['channel']][0]
+
         if plot_median:
             # Plot median if asked.
             # Have to make pulse again:
@@ -111,17 +117,13 @@ def plot_pulses(context, raw_records, run_id, time_range,
                          color='k',
                          label=f'Median Bas.: {median:.0f} ADC')
 
-            axes.axhline(median - p.config['hit_min_amplitude_nv'],
+            axes.axhline(median - thr,
                          ls='dotted', color='orange'
                          )
 
         hits = None  # needed for delet if false
         if plot_hits:
-            if detector_ending:
-                min_amplitude = p.config['hit_min_amplitude'+detector_ending]
-            else:
-                min_amplitude = straxen.hit_min_amplitude(p.config['hit_min_amplitude'])
-                min_amplitude = min_amplitude[rr_pulse[0]['channel']]
+            min_amplitude = thr
             
             axes.axhline(baseline - min_amplitude,
                          color='orange', label='Hitfinder threshold')
@@ -129,7 +131,11 @@ def plot_pulses(context, raw_records, run_id, time_range,
             hits = strax.find_hits(r_pulse,
                                    min_amplitude=min_amplitude
                                    )
-            le, re = p.config['save_outside_hits'+detector_ending]
+            if detector_ending != '_he':
+                # We don't have 'save_outside_hits_he' at all!
+                le, re = p.config['save_outside_hits'+detector_ending]
+            else:
+                le, re = p.config['save_outside_hits']
             start = (hits['time'] - r_pulse[0]['time']) / r_pulse[0]['dt'] - le
             end = (strax.endtime(hits) - r_pulse[0]['time']) / r_pulse[0]['dt'] + re
 
@@ -157,11 +163,9 @@ def plot_pulses(context, raw_records, run_id, time_range,
 def _yield_pulse_indices(records):
     """
     Function which yields indices of records which are within a pulse.
-
     Note:
         Only finds fragments of the pulse if record_i == 0 is within list
         of records.
-
     :yields: indices of fragments to make the corresponding pulse.
     """
     # Get record links and find start indicies:
