@@ -16,6 +16,15 @@ from .peak_processing import *
 from .position_reconstruction import *
 from . import position_reconstruction
 
+from . import event_area_per_channel
+from .event_area_per_channel import *
+
+from . import event_info
+from .event_info import *
+
+from . import event_patternfit
+from .event_patternfit import *
+
 from . import event_processing
 from .event_processing import *
 
