@@ -1,10 +1,11 @@
 import strax
 import numpy as np
+import numba
 import straxen
 from warnings import warn
 from .position_reconstruction import DEFAULT_POSREC_ALGO_OPTION
 from straxen.common import pax_file, get_resource, first_sr1_run, pre_apply_function
-from straxen.get_corrections import get_correction_from_cmt
+from straxen.get_corrections import get_correction_from_cmt, get_cmt_resource, is_cmt_option
 from straxen.itp_map import InterpolatingMap
 export, __all__ = strax.exporter()
 
@@ -107,9 +108,6 @@ class Events(strax.OverlapWindowPlugin):
         self.events_seen += len(result)
 
         return result
-        # TODO: someday investigate if/why loopplugin doesn't give
-        # anything if events do not contain peaks..
-        # Likely this has been resolved in 6a2cc6c
 
 
 @export
@@ -120,9 +118,14 @@ class Events(strax.OverlapWindowPlugin):
     strax.Option(
         name='force_main_before_alt', default=False,
         help="Make the alternate S1 (and likewise S2) the main S1 if "
-             "occurs before the main S1.")
+             "occurs before the main S1."),
+    strax.Option(
+        name='event_s1_min_coincidence',
+        default=2,
+        help="Event level S1 min coincidence. Should be >= s1_min_coincidence "
+             "in the peaklet classification"),
 )
-class EventBasics(strax.LoopPlugin):
+class EventBasics(strax.Plugin):
     """
     Computes the basic properties of the main/alternative S1/S2 within
     an event.
@@ -130,7 +133,7 @@ class EventBasics(strax.LoopPlugin):
     The main S2 and alternative S2 are given by the largest two S2-Peaks
     within the event. By default this is also true for S1.
     """
-    __version__ = '0.6.0'
+    __version__ = '1.0.0'
 
     depends_on = ('events',
                   'peak_basics',
@@ -140,50 +143,18 @@ class EventBasics(strax.LoopPlugin):
     data_kind = 'events'
     loop_over = 'events'
 
-    # Properties to store for each peak (main and alternate S1 and S2)
-    peak_properties = (
-        # name                dtype       comment
-        ('time',              np.int64,   'start time since unix epoch [ns]'),
-        ('center_time',       np.int64,   'weighted center time since unix epoch [ns]'),
-        ('endtime',           np.int64,   'end time since unix epoch [ns]'),
-        ('area',              np.float32, 'area, uncorrected [PE]'),
-        ('n_channels',        np.int32,   'count of contributing PMTs'),
-        ('n_competing',       np.float32, 'number of competing PMTs'),
-        ('max_pmt',           np.int16,   'PMT number which contributes the most PE'),
-        ('max_pmt_area',      np.float32, 'area in the largest-contributing PMT (PE)'),
-        ('range_50p_area',    np.float32, 'width, 50% area [ns]'),
-        ('range_90p_area',    np.float32, 'width, 90% area [ns]'),
-        ('rise_time',         np.float32, 'time between 10% and 50% area quantiles [ns]'),
-        ('area_fraction_top', np.float32, 'fraction of area seen by the top PMT array'))
-
     def infer_dtype(self):
         # Basic event properties
+        self._set_posrec_save()
+        self._set_dtype_requirements()
         dtype = []
         dtype += strax.time_fields
-        dtype += [('n_peaks', np.int32, 'Number of peaks in the event'),
+        dtype += [('n_peaks', np.int32,
+                   'Number of peaks in the event'),
                   ('drift_time', np.int32,
                    'Drift time between main S1 and S2 in ns')]
 
-        for i in [1, 2]:
-            # Peak indices
-            dtype += [
-                (f's{i}_index', np.int32,
-                 f'Main S{i} peak index in event'),
-                (f'alt_s{i}_index', np.int32,
-                 f'Alternate S{i} peak index in event')]
-
-            # Peak properties
-            for name, dt, comment in self.peak_properties:
-                dtype += [
-                    (f's{i}_{name}', dt, f'Main S{i} {comment}'),
-                    (f'alt_s{i}_{name}', dt, f'Alternate S{i} {comment}')]
-
-            # Drifts and delays
-            dtype += [
-                (f'alt_s{i}_interaction_drift_time', np.int32,
-                 f'Drift time using alternate S{i} [ns]'),
-                (f'alt_s{i}_delay', np.int32,
-                 f'Time between main and alternate S{i} [ns]')]
+        dtype += self._get_si_dtypes(self.peak_properties)
 
         dtype += [
             (f's2_x', np.float32,
@@ -193,26 +164,81 @@ class EventBasics(strax.LoopPlugin):
             (f'alt_s2_x', np.float32,
              f'Alternate S2 reconstructed X position, uncorrected [cm]'),
             (f'alt_s2_y', np.float32,
-             f'Alternate S2 reconstructed Y position, uncorrected [cm]')]
-
-        # area before main S2
-        dtype += [
+             f'Alternate S2 reconstructed Y position, uncorrected [cm]'),
             (f'area_before_main_s2', np.float32,
              f'Sum of areas before Main S2 [PE]'),
             (f'large_s2_before_main_s2', np.float32,
-             f'The largest S2 before the Main S2 [PE]')]
+             f'The largest S2 before the Main S2 [PE]')
+        ]
+
+        dtype += self._get_posrec_dtypes()
+        return dtype
+
+    def _set_dtype_requirements(self):
+        """Needs to be run before inferring dtype as it is needed there"""
+        # Properties to store for each peak (main and alternate S1 and S2)
+        self.peak_properties = (
+            # name                dtype       comment
+            ('time',              np.int64,   'start time since unix epoch [ns]'),
+            ('center_time',       np.int64,   'weighted center time since unix epoch [ns]'),
+            ('endtime',           np.int64,   'end time since unix epoch [ns]'),
+            ('area',              np.float32, 'area, uncorrected [PE]'),
+            ('n_channels',        np.int16,   'count of contributing PMTs'),
+            ('n_competing',       np.int32,   'number of competing peaks'),
+            ('max_pmt',           np.int16,   'PMT number which contributes the most PE'),
+            ('max_pmt_area',      np.float32, 'area in the largest-contributing PMT (PE)'),
+            ('range_50p_area',    np.float32, 'width, 50% area [ns]'),
+            ('range_90p_area',    np.float32, 'width, 90% area [ns]'),
+            ('rise_time',         np.float32, 'time between 10% and 50% area quantiles [ns]'),
+            ('area_fraction_top', np.float32, 'fraction of area seen by the top PMT array')
+        )
+
+    @staticmethod
+    def _get_si_dtypes(peak_properties):
+        """Get properties for S1/S2 from peaks directly"""
+        si_dtype = []
+        for s_i in [1, 2]:
+            # Peak indices
+            si_dtype += [
+                (f's{s_i}_index', np.int32, f'Main S{s_i} peak index in event'),
+                (f'alt_s{s_i}_index', np.int32, f'Alternate S{s_i} peak index in event')]
+
+            # Peak properties
+            for name, dt, comment in peak_properties:
+                si_dtype += [(f's{s_i}_{name}', dt, f'Main S{s_i} {comment}'),
+                             (f'alt_s{s_i}_{name}', dt, f'Alternate S{s_i} {comment}')]
+
+            # Drifts and delays
+            si_dtype += [
+                (f'alt_s{s_i}_interaction_drift_time', np.int32,
+                 f'Drift time using alternate S{s_i} [ns]'),
+                (f'alt_s{s_i}_delay', np.int32,
+                 f'Time between main and alternate S{s_i} [ns]')]
+        return si_dtype
+
+    def _set_posrec_save(self):
+        """
+        parse x_mlp et cetera if needed to get the algorithms used and
+        set required class attributes
+        """
+        posrec_fields = self.deps['peak_positions'].dtype_for('peak_positions').names
+        posrec_names = [d.split('_')[-1] for d in posrec_fields if 'x_' in d]
 
-        # parse x_mlp et cetera if needed to get the algorithms used.
-        self.pos_rec_labels = list(
-            set(d.split('_')[-1] for d in
-                self.deps['peak_positions'].dtype_for('peak_positions').names
-                if 'x_' in d))
         # Preserve order. "set" is not ordered and dtypes should always be ordered
+        self.pos_rec_labels = list(set(posrec_names))
         self.pos_rec_labels.sort()
 
+        self.posrec_save = [(xy + algo)
+                            for xy in ['x_', 'y_']
+                            for algo in self.pos_rec_labels]
+
+    def _get_posrec_dtypes(self):
+        """Get S2 positions for each of the position reconstruction algorithms"""
+        posrec_dtpye = []
+
         for algo in self.pos_rec_labels:
             # S2 positions
-            dtype += [
+            posrec_dtpye += [
                 (f's2_x_{algo}', np.float32,
                  f'Main S2 {algo}-reconstructed X position, uncorrected [cm]'),
                 (f's2_y_{algo}', np.float32,
@@ -222,103 +248,164 @@ class EventBasics(strax.LoopPlugin):
                 (f'alt_s2_y_{algo}', np.float32,
                  f'Alternate S2 {algo}-reconstructed Y position, uncorrected [cm]')]
 
-        return dtype
+        return posrec_dtpye
 
-    def compute_loop(self, event, peaks):
-        result = dict(n_peaks=len(peaks),
-                      time=event['time'],
-                      endtime=strax.endtime(event))
-        posrec_save = [(xy + algo)
-                       for xy in ['x_', 'y_']
-                       for algo in self.pos_rec_labels]
+    @staticmethod
+    def set_nan_defaults(buffer):
+        """
+        When constructing the dtype, take extra care to set values to
+        np.Nan / -1 (for ints) as 0 might have a meaning
+        """
+        for field in buffer.dtype.names:
+            if np.issubdtype(buffer.dtype[field], np.integer):
+                buffer[field][:] = -1
+            else:
+                buffer[field][:] = np.nan
 
-        if not len(peaks):
-            return result
-        main_s = dict()
-        secondary_s = dict()
+    def compute(self, events, peaks):
+        result = np.zeros(len(events), dtype=self.dtype)
+        self.set_nan_defaults(result)
 
+        split_peaks = strax.split_by_containment(peaks, events)
+        self.fill_events(result, events, split_peaks)
+        return result
+
+    # If copy_largest_peaks_into_event is ever numbafied, also numbafy this function
+    def fill_events(self, result_buffer, events, split_peaks):
+        """Loop over the events and peaks within that event"""
+        for event_i, _ in enumerate(events):
+            peaks_in_event_i = split_peaks[event_i]
+            n_peaks = len(peaks_in_event_i)
+
+            result_buffer[event_i]['time'] = events[event_i]['time']
+            result_buffer[event_i]['endtime'] = events[event_i]['endtime']
+            result_buffer[event_i]['n_peaks'] = n_peaks
+
+            if not n_peaks:
+                raise ValueError(f'No peaks within event?\n{events[event_i]}')
+
+            self.fill_result_i(result_buffer[event_i], peaks_in_event_i)
+
+    def fill_result_i(self, event, peaks):
+        """For a single event with the result_buffer"""
         # Consider S2s first, then S1s (to enable allow_posts2_s1s = False)
-        for s_i in [2, 1]:
+        largest_s2s, s2_idx = self.get_largest_sx_peaks(peaks, s_i=2)
 
-            # Which properties do we need?
-            to_store = [name for name, _, _ in self.peak_properties]
-            if s_i == 2:
-                to_store += ['x', 'y']
+        if self.config['force_main_before_alt']:
+            s2_order = np.argsort(largest_s2s['time'])
+            largest_s2s = largest_s2s[s2_order]
+            s2_idx = s2_idx[s2_order]
 
-            # Find all peaks of this type (S1 or S2)
-            s_mask = peaks['type'] == s_i
-            if not self.config['allow_posts2_s1s']:
-                # Only peaks *before* the main S2 are allowed to be
-                # the main or alternate S1
-                if s_i == 1 and result[f's2_index'] != -1:
-                    s_mask &= peaks['time'] < main_s[2]['time']
-            ss = peaks[s_mask]
-            s_indices = np.arange(len(peaks))[s_mask]
+        if not self.config['allow_posts2_s1s'] and len(largest_s2s):
+            s1_latest_time = largest_s2s[0]['time']
+        else:
+            s1_latest_time = np.inf
 
-            # Decide which of these signals is the main and alternate
-            if len(ss) > 1:
-                # Start by choosing the largest two signals
-                _alt_i, _main_i = np.argsort(ss['area'])[-2:]
-                if (self.config['force_main_before_alt']
-                        and ss[_alt_i]['time'] < ss[_main_i]['time']):
-                    # Promote alternate to main since it occurs earlier
-                    _alt_i, _main_i = _main_i, _alt_i
-            elif len(ss) == 1:
-                _main_i, _alt_i = 0, None
-            else:
-                _alt_i, _main_i = None, None
+        largest_s1s, s1_idx = self.get_largest_sx_peaks(
+            peaks,
+            s_i=1,
+            s1_before_time=s1_latest_time,
+            s1_min_coincidence=self.config['event_s1_min_coincidence'])
 
-            # Store main signal properties
-            if _main_i is None:
-                result[f's{s_i}_index'] = -1
-            else:
-                main_s[s_i] = ss[_main_i]
-                result[f's{s_i}_index'] = s_indices[_main_i]
-                for name in to_store:
-                    result[f's{s_i}_{name}'] = main_s[s_i][name]
+        self.set_sx_index(event, s1_idx, s2_idx)
+        self.set_event_properties(event, largest_s1s, largest_s2s, peaks)
+
+        # Loop over S1s and S2s and over main / alt.
+        for s_i, largest_s_i in enumerate([largest_s1s, largest_s2s], 1):
+            # Largest index 0 -> main sx, 1 -> alt sx
+            for largest_index, main_or_alt in enumerate(['s', 'alt_s']):
+                peak_properties_to_save = [name for name, _, _ in self.peak_properties]
                 if s_i == 2:
-                    for name in posrec_save:
-                        result[f's{s_i}_{name}'] = main_s[s_i][name]
-
-            # Store alternate signal properties
-            if _alt_i is None:
-                result[f'alt_s{s_i}_index'] = -1
-            else:
-                secondary_s[s_i] = ss[_alt_i]
-                result[f'alt_s{s_i}_index'] = s_indices[_alt_i]
-                for name in to_store:
-                    result[f'alt_s{s_i}_{name}'] = secondary_s[s_i][name]
-                if s_i == 2:
-                    for name in posrec_save:
-                        result[f'alt_s{s_i}_{name}'] = secondary_s[s_i][name]
-                # Compute delay time properties
-                result[f'alt_s{s_i}_delay'] = (secondary_s[s_i]['center_time']
-                                               - main_s[s_i]['center_time'])
+                    peak_properties_to_save += ['x', 'y']
+                    peak_properties_to_save += self.posrec_save
+                field_names = [f'{main_or_alt}{s_i}_{name}' for name in peak_properties_to_save]
+                self.copy_largest_peaks_into_event(event,
+                                                   largest_s_i,
+                                                   largest_index,
+                                                   field_names,
+                                                   peak_properties_to_save)
 
+    @staticmethod
+    @numba.njit
+    def set_event_properties(result, largest_s1s, largest_s2s, peaks):
+        """Get properties like drift time and area before main S2"""
         # Compute drift times only if we have a valid S1-S2 pair
-        if len(main_s) == 2:
-            result['drift_time'] = \
-                main_s[2]['center_time'] - main_s[1]['center_time']
-            if 1 in secondary_s:
-                result['alt_s1_interaction_drift_time'] = \
-                    main_s[2]['center_time'] - secondary_s[1]['center_time']
-            if 2 in secondary_s:
-                result['alt_s2_interaction_drift_time'] = \
-                    secondary_s[2]['center_time'] - main_s[1]['center_time']
+        if len(largest_s1s) > 0 and len(largest_s2s) > 0:
+            result['drift_time'] = largest_s2s[0]['center_time'] - largest_s1s[0]['center_time']
+            if len(largest_s1s) > 1:
+                result['alt_s1_interaction_drift_time'] = largest_s2s[0]['center_time'] - largest_s1s[1]['center_time']
+            if len(largest_s2s) > 1:
+                result['alt_s2_interaction_drift_time'] = largest_s2s[1]['center_time'] - largest_s1s[0]['center_time']
 
         # areas before main S2
-        if result[f's2_index'] != -1:
-            peaks_before_ms2 = peaks[peaks['time'] < main_s[2]['time']]
-            result['area_before_main_s2'] = sum(peaks_before_ms2['area'])
+        if len(largest_s2s):
+            peaks_before_ms2 = peaks[peaks['time'] < largest_s2s[0]['time']]
+            result['area_before_main_s2'] = np.sum(peaks_before_ms2['area'])
 
             s2peaks_before_ms2 = peaks_before_ms2[peaks_before_ms2['type'] == 2]
             if len(s2peaks_before_ms2) == 0:
                 result['large_s2_before_main_s2'] = 0
             else:
-                result['large_s2_before_main_s2'] = max(s2peaks_before_ms2['area'])
-
+                result['large_s2_before_main_s2'] = np.max(s2peaks_before_ms2['area'])
         return result
 
+    @staticmethod
+    # @numba.njit <- works but slows if fill_events is not numbafied
+    def get_largest_sx_peaks(peaks,
+                             s_i,
+                             s1_before_time=np.inf,
+                             s1_min_coincidence=0,
+                             number_of_peaks=2):
+        """Get the largest S1/S2. For S1s allow a min coincidence and max time"""
+        # Find all peaks of this type (S1 or S2)
+        s_mask = peaks['type'] == s_i
+        if s_i == 1:
+            s_mask &= peaks['time'] < s1_before_time
+            s_mask &= peaks['tight_coincidence'] >= s1_min_coincidence
+
+        selected_peaks = peaks[s_mask]
+        s_index = np.arange(len(peaks))[s_mask]
+        largest_peaks = np.argsort(selected_peaks['area'])[-number_of_peaks:][::-1]
+        return selected_peaks[largest_peaks], s_index[largest_peaks]
+
+    # If only we could numbafy this... Unfortunatly we cannot.
+    # Perhaps we could one day consider doing something like strax.copy_to_buffer
+    @staticmethod
+    def copy_largest_peaks_into_event(result,
+                                      largest_s_i,
+                                      main_or_alt_index,
+                                      result_fields,
+                                      peak_fields,
+                                      ):
+        """
+        For one event, write all the peak_fields (e.g. "area") of the peak
+        (largest_s_i) into their associated field in the event (e.g. s1_area),
+        main_or_alt_index differentiates between main (index 0) and alt (index 1)
+        """
+        index_not_in_list_of_largest_peaks = main_or_alt_index >= len(largest_s_i)
+        if index_not_in_list_of_largest_peaks:
+            # There is no such peak. E.g. main_or_alt_index == 1 but largest_s_i = ["Main S1"]
+            # Asking for index 1 doesn't work on a len 1 list of peaks.
+            return
+
+        for i, ev_field in enumerate(result_fields):
+            p_field = peak_fields[i]
+            if p_field not in ev_field:
+                raise ValueError("Event fields must derive from the peak fields")
+            result[ev_field] = largest_s_i[main_or_alt_index][p_field]
+
+    @staticmethod
+    # @numba.njit <- works but slows if fill_events is not numbafied
+    def set_sx_index(res, s1_idx, s2_idx):
+        if len(s1_idx):
+            res['s1_index'] = s1_idx[0]
+            if len(s1_idx) > 1:
+                res['alt_s1_index'] = s1_idx[1]
+        if len(s2_idx):
+            res['s2_index'] = s2_idx[0]
+            if len(s2_idx) > 1:
+                res['alt_s2_index'] = s2_idx[1]
+
 
 @export
 @strax.takes_config(
@@ -380,21 +467,22 @@ class EventPositions(strax.Plugin):
 
     def setup(self):
 
-        is_CMT = isinstance(self.config['fdc_map'], tuple)
         self.electron_drift_velocity = get_correction_from_cmt(self.run_id, self.config['electron_drift_velocity'])
         self.electron_drift_time_gate = get_correction_from_cmt(self.run_id, self.config['electron_drift_time_gate'])
-        if is_CMT:
-            config_name, cmt_version, is_nt = self.config['fdc_map']
-            map_algo = f'{config_name}_{self.config["default_reconstruction_algorithm"]}'
-            cmt_conf = map_algo, cmt_version, is_nt
-            self.map = InterpolatingMap(
-                get_resource(get_correction_from_cmt(self.run_id, cmt_conf), fmt='binary'))
-            self.map.scale_coordinates([1., 1., -self.electron_drift_velocity])
-
-        elif isinstance(self.config['fdc_map'], str):
+        
+        if isinstance(self.config['fdc_map'], str):
             self.map = InterpolatingMap(
                 get_resource(self.config['fdc_map'], fmt='binary'))
 
+        elif is_cmt_option(self.config['fdc_map']):
+            self.map = InterpolatingMap(
+                get_cmt_resource(self.run_id,
+                                 tuple(['suffix',
+                                        self.config['default_reconstruction_algorithm'],
+                                        *self.config['fdc_map']]),
+                                 fmt='binary'))
+            self.map.scale_coordinates([1., 1., - self.electron_drift_velocity])
+
         else:
             raise NotImplementedError('FDC map format not understood.')
 
@@ -485,19 +573,24 @@ class CorrectedAreas(strax.Plugin):
              ] + strax.time_fields
 
     def setup(self):
-        is_CMT = isinstance(self.config['s1_xyz_correction_map'], tuple)
-        if is_CMT:
-            config_name, cmt_version, is_nt = self.config['s1_xyz_correction_map']
-            map_algo = f'{config_name}_{self.config["default_reconstruction_algorithm"]}'
-            cmt_conf = map_algo, cmt_version, is_nt
-            self.s1_map = InterpolatingMap(get_resource(get_correction_from_cmt(self.run_id, cmt_conf)))
-        else:
-            self.s1_map = InterpolatingMap(
-                get_resource(self.config['s1_xyz_correction_map']))
+        self.elife = get_correction_from_cmt(self.run_id, self.config['elife_conf'])
+
+        if isinstance(self.config['s1_xyz_correction_map'], str):
+            self.config['s1_xyz_correction_map'] = [self.config['s1_xyz_correction_map']]
+        if isinstance(self.config['s2_xy_correction_map'], str):
+            self.config['s2_xy_correction_map'] = [self.config['s2_xy_correction_map']]
+
+        self.s1_map = InterpolatingMap(
+            get_cmt_resource(self.run_id,
+                             tuple(['suffix',
+                                    self.config['default_reconstruction_algorithm'],
+                                    *self.config['s1_xyz_correction_map']]),
+                             fmt='text'))
 
         self.s2_map = InterpolatingMap(
-                get_resource(get_correction_from_cmt(self.run_id, self.config['s2_xy_correction_map'])))
-        self.elife = get_correction_from_cmt(self.run_id, self.config['elife_conf'])
+            get_cmt_resource(self.run_id,
+                             tuple([*self.config['s2_xy_correction_map']]),
+                             fmt='text'))
 
     def compute(self, events):
         # S1 corrections depend on the actual corrected event position.
