@@ -117,16 +117,16 @@ class PeakPositionsBaseNT(strax.Plugin):
             return model_from_config
 
         # Use CMT
-        model_file = straxen.get_config_from_cmt(self.run_id, model_from_config)
+        model_file = straxen.get_correction_from_cmt(self.run_id, model_from_config)
         return model_file
 
 @export
 @strax.takes_config(
     strax.Option('mlp_model',
                  help='Neural network model.' 
-                      'If CMT, specify as (CMT_model, (mlp_model, ONLINE), True)))'
+                      'If CMT, specify as (mlp_model, ONLINE, True)'
                       'Set to None to skip the computation of this plugin.',
-                 default=("CMT_model", ('mlp_model', "ONLINE"), True)
+                 default=('mlp_model', "ONLINE", True)
                 )
 )
 class PeakPositionsMLP(PeakPositionsBaseNT):
@@ -139,9 +139,9 @@ class PeakPositionsMLP(PeakPositionsBaseNT):
 @strax.takes_config(
     strax.Option('gcn_model',
                  help='Neural network model.' 
-                      'If CMT, specify as (CMT_model, (gcn_model, ONLINE), True)))'
+                      'If CMT, specify as  (gcn_model, ONLINE, True)'
                       'Set to None to skip the computation of this plugin.',
-                 default=("CMT_model", ('gcn_model', "ONLINE"), True)
+                 default=('gcn_model', "ONLINE", True)
                 )
 )
 class PeakPositionsGCN(PeakPositionsBaseNT):
@@ -155,9 +155,9 @@ class PeakPositionsGCN(PeakPositionsBaseNT):
 @strax.takes_config(
     strax.Option('cnn_model',
                  help='Neural network model.' 
-                      'If CMT, specify as (CMT_model, (cnn_model, ONLINE), True)))'
+                      'If CMT, specify as (cnn_model, ONLINE, True)'
                       'Set to None to skip the computation of this plugin.',
-                 default=("CMT_model", ('cnn_model', "ONLINE"), True)
+                 default=('cnn_model', "ONLINE", True)
                 )
 )
 class PeakPositionsCNN(PeakPositionsBaseNT):
