@@ -5,25 +5,34 @@ import numpy as np
 import strax
 import straxen
 
+from straxen.get_corrections import is_cmt_option
+
 export, __all__ = strax.exporter()
 __all__ += ['NO_PULSE_COUNTS']
 
 # These are also needed in peaklets, since hitfinding is repeated
 HITFINDER_OPTIONS = tuple([
     strax.Option(
-        'hit_min_amplitude',
-        default='pmt_commissioning_initial',
-        help='Minimum hit amplitude in ADC counts above baseline. '
-             'See straxen.hit_min_amplitude for options.'
+    'hit_min_amplitude', track=True,
+    default=('hit_thresholds_tpc', 'ONLINE', True),
+    help='Minimum hit amplitude in ADC counts above baseline. '
+            'Specify as a tuple of length n_tpc_pmts, or a number,'
+            'or a string like "pmt_commissioning_initial" which means calling'
+            'hitfinder_thresholds.py'
+            'or a tuple like (correction=str, version=str, nT=boolean),'
+            'which means we are using cmt.'
     )])
 
 HITFINDER_OPTIONS_he = tuple([
     strax.Option(
-        'hit_min_amplitude_he', track=True,
-        default="pmt_commissioning_initial_he",
-        child_option=True, parent_option_name='hit_min_amplitude',
-        help='Minimum hit amplitude in ADC counts above baseline for the high energy channels. '
-             'See straxen.hit_min_amplitude for options.'
+    'hit_min_amplitude_he',
+    default=('hit_thresholds_he', 'ONLINE', True), track=True,
+    help='Minimum hit amplitude in ADC counts above baseline. '
+            'Specify as a tuple of length n_tpc_pmts, or a number,'
+            'or a string like "pmt_commissioning_initial" which means calling'
+            'hitfinder_thresholds.py'
+            'or a tuple like (correction=str, version=str, nT=boolean),'
+            'which means we are using cmt.'
     )])
 
 HE_PREAMBLE = """High energy channels: attenuated signals of the top PMT-array\n"""
@@ -146,9 +155,20 @@ class PulseProcessing(strax.Plugin):
                 (self.config['hev_gain_model'][0] != 'disabled')
                 and self.config['tail_veto_threshold'])
         if self.hev_enabled:
-            self.to_pe = straxen.get_to_pe(self.run_id,
-                                           self.config['hev_gain_model'],
-                                           self.config['n_tpc_pmts'])
+            self.to_pe = straxen.get_correction_from_cmt(self.run_id,
+                                           self.config['hev_gain_model'])
+
+        # Check config of `hit_min_amplitude` and define hit thresholds
+        # if cmt config
+        if is_cmt_option(self.config['hit_min_amplitude']):
+            self.hit_thresholds = straxen.get_correction_from_cmt(self.run_id,
+                self.config['hit_min_amplitude'])
+        # if hitfinder_thresholds config
+        elif isinstance(self.config['hit_min_amplitude'], str):
+            self.hit_thresholds = straxen.hit_min_amplitude(
+                self.config['hit_min_amplitude'])
+        else: # int or array
+            self.hit_thresholds = self.config['hit_min_amplitude']
         
     def compute(self, raw_records, start, end):
         if self.config['check_raw_record_overlaps']:
@@ -200,10 +220,7 @@ class PulseProcessing(strax.Plugin):
         if len(r):
             # Find hits
             # -- before filtering,since this messes with the with the S/N
-            hits = strax.find_hits(
-                r,
-                min_amplitude=straxen.hit_min_amplitude(
-                    self.config['hit_min_amplitude']))
+            hits = strax.find_hits(r, min_amplitude=self.hit_thresholds)
 
             if self.config['pmt_pulse_filter']:
                 # Filter to concentrate the PMT pulses
@@ -252,7 +269,18 @@ class PulseProcessingHighEnergy(PulseProcessing):
     def setup(self):
         self.hev_enabled = False
         self.config['n_tpc_pmts'] = self.config['n_he_pmts']
-        self.config['hit_min_amplitude'] = self.config['hit_min_amplitude_he']
+        
+        # Check config of `hit_min_amplitude` and define hit thresholds
+        # if cmt config
+        if is_cmt_option(self.config['hit_min_amplitude_he']):
+            self.hit_thresholds = straxen.get_correction_from_cmt(self.run_id,
+                self.config['hit_min_amplitude_he'])
+        # if hitfinder_thresholds config
+        elif isinstance(self.config['hit_min_amplitude_he'], str):
+            self.hit_thresholds = straxen.hit_min_amplitude(
+                self.config['hit_min_amplitude_he'])
+        else: # int or array
+            self.hit_thresholds = self.config['hit_min_amplitude_he']
 
     def compute(self, raw_records_he, start, end):
         result = super().compute(raw_records_he, start, end)
