@@ -4,6 +4,9 @@ from immutabledict import immutabledict
 
 import strax
 import straxen
+
+from straxen.get_corrections import is_cmt_option
+
 export, __all__ = strax.exporter()
 
 
@@ -17,9 +20,13 @@ MV_PREAMBLE = 'Muno-Veto Plugin: Same as the corresponding nVETO-PLugin.\n'
         help='Save (left, right) samples besides hits; cut the rest'),
     strax.Option(
         'hit_min_amplitude_nv',
-        default=20, track=True,
+        default=('hit_thresholds_nv', 'ONLINE', True), track=True,
         help='Minimum hit amplitude in ADC counts above baseline. '
-             'Specify as a tuple of length 120, or a number.'),
+             'Specify as a tuple of length n_nveto_pmts, or a number, '
+             'or a string like "pmt_commissioning_initial" which means calling '
+             'hitfinder_thresholds.py, '
+             'or a tuple like (correction=str, version=str, nT=boolean), '
+             'which means we are using cmt.'),
     strax.Option(
         'min_split_nv',
         default=0.063, track=True,
@@ -40,8 +47,9 @@ MV_PREAMBLE = 'Muno-Veto Plugin: Same as the corresponding nVETO-PLugin.\n'
     strax.Option('channel_map', track=False, type=immutabledict,
                  help="immutabledict mapping subdetector to (min, max) "
                       "channel number."),
-    strax.Option('gain_model_nv', default=("CMT_model", ("to_pe_model_nv", "ONLINE")),
-             help='PMT gain model. Specify as (model_type, model_config)'),
+    strax.Option('gain_model_nv',
+                 default=("to_pe_model_nv", "ONLINE", True),
+                 help='PMT gain model. Specify as (model_type, model_config, nT = True)'),
 )
 class nVETOHitlets(strax.Plugin):
     """
@@ -78,17 +86,28 @@ class nVETOHitlets(strax.Plugin):
         self.channel_range = self.config['channel_map']['nveto']
         self.n_channel = (self.channel_range[1] - self.channel_range[0]) + 1
 
-        to_pe = straxen.get_to_pe(self.run_id,
-                                  self.config['gain_model_nv'],
-                                  self.n_channel)
+        to_pe = straxen.get_correction_from_cmt(self.run_id,
+                                  self.config['gain_model_nv'])
 
         
         # Create to_pe array of size max channel:
         self.to_pe = np.zeros(self.channel_range[1] + 1, dtype=np.float32)
         self.to_pe[self.channel_range[0]:] = to_pe[:]
 
+        # Check config of `hit_min_amplitude_nv` and define hit thresholds
+        # if cmt config
+        if is_cmt_option(self.config['hit_min_amplitude_nv']):
+            self.hit_thresholds = straxen.get_correction_from_cmt(self.run_id,
+                self.config['hit_min_amplitude_nv'])
+        # if hitfinder_thresholds config
+        elif isinstance(self.config['hit_min_amplitude_nv'], str):
+            self.hit_thresholds = straxen.hit_min_amplitude(
+                self.config['hit_min_amplitude_nv'])
+        else: # int or array
+            self.hit_thresholds = self.config['hit_min_amplitude_nv']
+
     def compute(self, records_nv, start, end):
-        hits = strax.find_hits(records_nv, min_amplitude=self.config['hit_min_amplitude_nv'])
+        hits = strax.find_hits(records_nv, min_amplitude=self.hit_thresholds)
         hits = remove_switched_off_channels(hits, self.to_pe)
 
         temp_hitlets = strax.create_hitlets_from_hits(hits,
@@ -142,10 +161,13 @@ def remove_switched_off_channels(hits, to_pe):
         help='Save (left, right) samples besides hits; cut the rest'),
     strax.Option(
         'hit_min_amplitude_mv',
-        default=80, track=True,
-        child_option=True, parent_option_name='hit_min_amplitude_nv',
+        default=('hit_thresholds_mv', 'ONLINE', True), track=True,
         help='Minimum hit amplitude in ADC counts above baseline. '
-             'Specify as a tuple of length 120, or a number.'),
+             'Specify as a tuple of length n_mveto_pmts, or a number, '
+             'or a string like "pmt_commissioning_initial" which means calling '
+             'hitfinder_thresholds.py, '
+             'or a tuple like (correction=str, version=str, nT=boolean),'
+             'which means we are using cmt.'),
     strax.Option(
         'min_split_mv', 
         default=100, track=True,
@@ -167,7 +189,8 @@ def remove_switched_off_channels(hits, to_pe):
         default=False, track=True,
         child_option=True, parent_option_name='entropy_square_data_nv',
         help='Parameter which decides if data is first squared before normalized and compared to the template.'),
-    strax.Option('gain_model_mv', default=("to_pe_constant", "adc_mv"),
+    strax.Option('gain_model_mv',
+                 default=("to_pe_model_mv", "ONLINE", True),
                  child_option=True, parent_option_name='gain_model_nv',
                  help='PMT gain model. Specify as (model_type, model_config)'),
 )
@@ -186,13 +209,24 @@ class muVETOHitlets(nVETOHitlets):
         self.channel_range = self.config['channel_map']['mv']
         self.n_channel = (self.channel_range[1] - self.channel_range[0]) + 1
 
-        to_pe = straxen.get_to_pe(self.run_id,
-                                  self.config['gain_model_mv'],
-                                  self.n_channel)
+        to_pe = straxen.get_correction_from_cmt(self.run_id,
+                                  self.config['gain_model_mv'])
 
         # Create to_pe array of size max channel:
         self.to_pe = np.zeros(self.channel_range[1] + 1, dtype=np.float32)
         self.to_pe[self.channel_range[0]:] = to_pe[:]
 
+        # Check config of `hit_min_amplitude_mv` and define hit thresholds
+        # if cmt config
+        if is_cmt_option(self.config['hit_min_amplitude_mv']):
+            self.hit_thresholds = straxen.get_correction_from_cmt(self.run_id,
+                self.config['hit_min_amplitude_mv'])
+        # if hitfinder_thresholds config
+        elif isinstance(self.config['hit_min_amplitude_mv'], str):
+            self.hit_thresholds = straxen.hit_min_amplitude(
+                self.config['hit_min_amplitude_mv'])
+        else: # int or array
+            self.hit_thresholds = self.config['hit_min_amplitude_mv']
+
     def compute(self, records_mv, start, end):
         return super().compute(records_mv, start, end)
